==> kdegames-3.1.3.tar.bz2: kdegames-3.1.3/libksirtet/common/misc_ui.h <==
#ifndef COMMON_MISC_UI_H
#define COMMON_MISC_UI_H

#include <qcanvas.h>
#include <qptrvector.h>
#include <qhbox.h>


class BaseBoard;

/*****************************************************************************/
class ShowNextPiece : public QCanvasView
{
 Q_OBJECT
 public:
    ShowNextPiece(BaseBoard *, QWidget *parent);

	QSize sizeHint() const;
	QSizePolicy sizePolicy() const;

 private slots:
    void blockSizeChanged() { updateGeometry(); }
};

/*****************************************************************************/
class Shadow : public QWidget
{
 Q_OBJECT
 public:
    Shadow(BaseBoard *, QWidget *parent);

	QSize sizeHint() const;
	QSizePolicy sizePolicy() const;

    void setDisplay(bool show);

 private slots:
	void blockSizeChanged() { updateGeometry(); }

 private:
	int              _xOffset;
	const BaseBoard *_board;
    bool             _show;

    void paintEvent(QPaintEvent *);
};

/****************************************************************************/
class GiftShower : public QWidget
{
 Q_OBJECT
 public:
    GiftShower(QWidget *parent);

	QSize sizeHint() const;
	QSizePolicy sizePolicy() const;

 public slots:
    void set();

 protected:
	void paintEvent(QPaintEvent *);

 private slots:
    void timeout();

 private:
	bool _state;
};

/*****************************************************************************/
class Led;

class GiftPool : public QHBox
{
 Q_OBJECT
 public:
    GiftPool(QWidget *parent);

	QSize sizeHint() const;
	QSizePolicy sizePolicy() const;

    void reset();
	void put(uint);
	uint take();
	bool pending() const { return ready; }

 private slots:
    void timeout() { ready = true; }

 private:
	QPtrVector<Led> leds;
	uint         _timeout, nb;
	bool         ready;
};

#endif

==> kdegames-3.4.1.tar.bz2: kdegames-3.4.1/libksirtet/common/misc_ui.h <==
#ifndef COMMON_MISC_UI_H
#define COMMON_MISC_UI_H

#include <qcanvas.h>
#include <qptrvector.h>
#include <qhbox.h>

#include <kgameprogress.h>

#include "base/board.h"

/*****************************************************************************/
class ShowNextPiece : public FixedCanvasView
{
 Q_OBJECT
 public:
    ShowNextPiece(BaseBoard *, QWidget *parent);
};

/*****************************************************************************/
class Shadow : public QWidget
{
 Q_OBJECT
 public:
    Shadow(BaseBoard *, QWidget *parent);

    virtual QSize sizeHint() const;
    virtual QSizePolicy sizePolicy() const;
    void setDisplay(bool show);

 private:
    int              _xOffset;
    const BaseBoard *_board;
    bool             _show;

    void paintEvent(QPaintEvent *);
};

/*****************************************************************************/
class Led;

class GiftPool : public QHBox
{
 Q_OBJECT
 public:
    GiftPool(QWidget *parent);

    virtual QSize sizeHint() const;
    virtual QSizePolicy sizePolicy() const;

    void reset();
	void put(uint);
	uint take();
	bool pending() const { return ready; }

 private slots:
    void timeout() { ready = true; }

 private:
	QPtrVector<Led> leds;
	uint         _timeout, nb;
	bool         ready;
};


/*****************************************************************************/
class PlayerProgress : public KGameProgress
{
  Q_OBJECT
public:
  PlayerProgress(BaseBoard *board, QWidget *parent = 0, const char *name = 0);
  
  virtual QSize sizeHint() const;
  virtual QSizePolicy sizePolicy() const;
  
private:
  BaseBoard *_board;
};

#endif
